OC.L10N.register(
    "core",
    {
    "Please select a file." : "Válasszon egy fájlt.",
    "File is too big" : "A fájl túl nagy",
    "The selected file is not an image." : "A kiválasztott fájl nem kép.",
    "The selected file cannot be read." : "A kiválasztott fájl nem olvasható.",
    "The file was uploaded" : "A fájl feltöltve",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "A feltöltött fájl meghaladja a php.ini-ben szereplő upload_max_filesize direktívában megadott méretet",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "A feltöltött fájl meghaladja a HTML űrlapon megadott MAX_FILE_SIZE direktívában meghatározott méretet",
    "The file was only partially uploaded" : "A fájl csak részben került feltöltésre",
    "No file was uploaded" : "Egyetlen fájl sem töltődött fel",
    "Missing a temporary folder" : "Hiányzik egy ideiglenes mappa",
    "Could not write file to disk" : "Nem lehet a fájlt lemezre írni",
    "A PHP extension stopped the file upload" : "Egy PHP kiterjesztés megállította a fájl feltöltését",
    "Invalid file provided" : "Érvénytelen fájl van megadva",
    "No image or file provided" : "Nincs kép vagy fájl megadva",
    "Unknown filetype" : "Ismeretlen fájltípus",
    "An error occurred. Please contact your admin." : "Hiba történt. Lépjen kapcsolatba a rendszergazdával.",
    "Invalid image" : "Érvénytelen kép",
    "State token does not match" : "Az állapottoken nem megfelelő",
    "Invalid app password" : "Érvénytelen alkalmazásjelszó",
    "Could not complete login" : "A bejelentkezés nem fejezhető be",
    "State token missing" : "Az állapottoken hiányzik",
    "Your login token is invalid or has expired" : "A bejelentkezési token érvénytelen vagy lejárt",
    "Please use original client" : "Használja az eredeti klienset",
    "This community release of Nextcloud is unsupported and push notifications are limited." : "A Nextcloud e közösségi kiadása nem támogatott, és a leküldéses értesítések korlátozottak.",
    "Login" : "Bejelentkezés",
    "Unsupported email length (>255)" : "Nem támogatott hosszúságú e-mail-cím (>255)",
    "Password reset is disabled" : "Jelszó visszaállítás letiltva",
    "Could not reset password because the token is expired" : "A jelszót nem lehet visszaállítani, mert a token lejárt",
    "Could not reset password because the token is invalid" : "A jelszót nem lehet visszaállítani, mert a token érvénytelen",
    "Password is too long. Maximum allowed length is 469 characters." : "A jelszó túl hosszú. A legnagyobb megengedett hossz 469 karakter.",
    "%s password reset" : "%s jelszó visszaállítás",
    "Password reset" : "Jelszó visszaállítás",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Kattintson a lenti gombra a jelszava visszaállításához. Ha ezt nem Ön kérte, akkor hagyja figyelmen kívül ezt a levelet.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Kattintson a lenti hivatkozásra a jelszava visszaállításához. Ha ezt nem Ön kérte, akkor hagyja figyelmen kívül ezt a levelet.",
    "Reset your password" : "Jelszó visszaállítása",
    "The given provider is not available" : "A megadott szolgáltató nem érhető el",
    "Task not found" : "A feladat nem található",
    "Internal error" : "Belső hiba",
    "Not found" : "Nem található",
    "Node is locked" : "A csomópont zárolva van",
    "Bad request" : "Hibás kérés",
    "Input text is too long" : "A bementi szöveg túl hosszú",
    "Requested task type does not exist" : "A kért feladattípus nem létezik",
    "Necessary language model provider is not available" : "A szükséges nyelvimodell-szolgáltató nem érhető el",
    "No text to image provider is available" : "Nem érhető el szövegből képet előállító szolgáltató",
    "Image not found" : "A kép nem található",
    "No translation provider available" : "Nem érhető el fordítási szolgáltató",
    "Could not detect language" : "Nem sikerült észlelni a nyelvet",
    "Unable to translate" : "Nem fordítható le",
    "No valid filters provided" : "Nincs érvényes szűrő megadva",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "Javítási lépés:",
    "Repair info:" : "Javítási információ:",
    "Repair warning:" : "Javítási figyelmeztetés:",
    "Repair error:" : "Javítási hiba:",
    "Nextcloud Server" : "Nextcloud kiszolgáló",
    "Some of your link shares have been removed" : "Néhány megosztási hivatkozása eltávolításra került",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Egy biztonsági hiba miatt el kellett távolítsunk néhány megosztási hivatkozását. További információkért lásd a lenti hivatkozást.",
    "The account limit of this instance is reached." : "Elérte ennek a példánynak a fiókkorlátját.",
    "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Adja meg az előfizetési kulcsát a támogatási alkalmazásban, hogy megnövelje a fiókkorlátot. Ez a Nextcloud vállalati ajánlatainak további előnyeit is biztosítja, és határozottan ajánlott a céges üzemeltetés esetén.",
    "Learn more ↗" : "Tudjon meg többet ↗",
    "Preparing update" : "Felkészülés a frissítésre",
    "Please use the command line updater because updating via browser is disabled in your config.php." : "Használja a parancssoros frissítőt, mert a böngészőbeli frissítés ki van kapcsolva a config.php fájlban.",
    "Turned on maintenance mode" : "Karbantartási mód bekapcsolva",
    "Turned off maintenance mode" : "Karbantartási mód kikapcsolva",
    "Maintenance mode is kept active" : "Karbantartási mód aktiválva maradt",
    "Updating database schema" : "Adatbázis séma frissítése",
    "Updated database" : "Adatbázis frissítve",
    "Update app \"%s\" from App Store" : "A(z) „%s” alkalmazás frissítése az alkalmazástárból",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Ellenőrzés, hogy a %s adatbázis sémája frissíthető-e (ez az adatbázis méretétől függően hosszabb ideig is eltarthat)",
    "Updated \"%1$s\" to %2$s" : "„%1$s” frissítve erre: %2$s",
    "Set log level to debug" : "Naplózási szint beállítása hibakeresésre",
    "Reset log level" : "Naplózási szint visszaállítása",
    "Starting code integrity check" : "Kódintegritási ellenőrzés indítása",
    "Finished code integrity check" : "Kódintegritási ellenőrzés befejezve",
    "%s (incompatible)" : "%s (nem kompatibilis)",
    "The following apps have been disabled: %s" : "A következő alkalmazások le lettek tiltva: %s",
    "Already up to date" : "Már naprakész",
    "Windows Command Script" : "Windows-parancsfájl",
    "Electronic book document" : "Elektronikus könyvdokumentum",
    "TrueType Font Collection" : "TrueType betűkészlet-gyűjtemény",
    "Web Open Font Format" : "Nyílt webes betűkészlet-formátum",
    "GPX geographic data" : "GPX földrajzi adatok",
    "Gzip archive" : "Gzip-archívum",
    "Adobe Illustrator document" : "Adobe Illustrator-dokumentum",
    "Java source code" : "Java-forrásfájl",
    "JavaScript source code" : "JavaScript-forrásfájl",
    "JSON document" : "JSON-dokumentum",
    "Microsoft Access database" : "Microsoft Excel-adatbázis",
    "Microsoft OneNote document" : "Microsfot OneNote-dokumentum",
    "Microsoft Word document" : "Microsoft Word dokumentum",
    "Unknown" : "Ismeretlen",
    "PDF document" : "PDF-dokumentum",
    "PostScript document" : "PostScript-dokumentum",
    "RSS summary" : "RSS-összefoglaló",
    "Android package" : "Android-csomag",
    "KML geographic data" : "KML földrajzi adatok",
    "KML geographic compressed data" : "KML tömörített földrajzi adatok",
    "Lotus Word Pro document" : "Lotus Word Pro-dokumentum",
    "Excel spreadsheet" : "Excel-munkafüzet",
    "Excel add-in" : "Excel-bővítmény",
    "Excel 2007 binary spreadsheet" : "Excel 2007 bináris munkafüzet",
    "Excel spreadsheet template" : "Excel-munkafüzetsablon",
    "Outlook Message" : "Outlook-üzenet",
    "PowerPoint presentation" : "PowerPoint-bemutató",
    "PowerPoint add-in" : "PowerPoint-bővítmény",
    "PowerPoint presentation template" : "PowerPoint-bemutatósablon",
    "Word document" : "Word-dokumentum",
    "ODF formula" : "ODF-képlet",
    "ODG drawing" : "ODG-rajz",
    "ODG drawing (Flat XML)" : "ODG-rajz (lapos XML)",
    "ODG template" : "ODG-sablon",
    "ODP presentation" : "ODP-bemutató",
    "ODP presentation (Flat XML)" : "ODP-bemutató (lapos XML)",
    "ODP template" : "ODF-sablon",
    "ODS spreadsheet" : "ODS-munkafüzet",
    "ODS spreadsheet (Flat XML)" : "ODS-munkafüzet (lapos XML)",
    "ODS template" : "ODS-sablon",
    "ODT document" : "ODT-dokumentum",
    "ODT document (Flat XML)" : "ODT-sablon (lapos XML)",
    "ODT template" : "ODT-sablon",
    "PowerPoint 2007 presentation" : "PowerPoint 2007-bemutató",
    "PowerPoint 2007 show" : "PowerPoint 2007-vetítés",
    "PowerPoint 2007 presentation template" : "PowerPoint 2007-bemutatósablon",
    "Excel 2007 spreadsheet" : "Excel 2007-munkafüzet",
    "Excel 2007 spreadsheet template" : "Excel 2007-munkafüzetsablon",
    "Word 2007 document" : "Word 2007-dokumentum",
    "Word 2007 document template" : "Word 2007-dokumentumsablon",
    "Microsoft Visio document" : "Microsoft Visio-dokumentum",
    "WordPerfect document" : "WordPerfect-dokumentum",
    "7-zip archive" : "7-zip-archívum",
    "Blender scene" : "Blender-jelenet",
    "Bzip2 archive" : "Bzip2-archívum",
    "Debian package" : "Debian-csomag",
    "FictionBook document" : "FictionBook-dokumentum",
    "Unknown font" : "Ismeretlen betűkészlet",
    "Krita document" : "Krita-dokumentum",
    "Mobipocket e-book" : "Mobipocket ekönyv",
    "Windows Installer package" : "Windows Installer-csomag",
    "Perl script" : "Perl-parancsfájl",
    "PHP script" : "PHP-parancsfájl",
    "Tar archive" : "Tar-archívum",
    "XML document" : "XML-dokumentum",
    "YAML document" : "YAML-dokumentum",
    "Zip archive" : "Zip-archívum",
    "Zstandard archive" : "Zstandard-archívum",
    "AAC audio" : "AAC-hang",
    "FLAC audio" : "FLAC-hang",
    "MPEG-4 audio" : "MPEG-4-hang",
    "MP3 audio" : "MP3-hang",
    "Ogg audio" : "Ogg-hang",
    "RIFF/WAVe standard Audio" : "RIFF/WAVe szabványos hang",
    "WebM audio" : "WebM-hang",
    "MP3 ShoutCast playlist" : "MP3 ShoutCast-lejátszólista",
    "Windows BMP image" : "Windows BMP-kép",
    "Better Portable Graphics image" : "Better Portable Graphics-kép",
    "EMF image" : "EMF-kép",
    "GIF image" : "GIF-kép",
    "HEIC image" : "HEIC-kép",
    "HEIF image" : "HEIF-kép",
    "JPEG-2000 JP2 image" : "JPEG-2000 JP2-kép",
    "JPEG image" : "JPEG-kép",
    "PNG image" : "PNG-kép",
    "SVG image" : "SVG-kép",
    "Truevision Targa image" : "Truevision Targa-kép",
    "TIFF image" : "TIFF-kép",
    "WebP image" : "WebP-kép",
    "Digital raw image" : "Digitális nyerskép",
    "Windows Icon" : "Windows-ikon",
    "Email message" : "E-mail-üzenet",
    "VCS/ICS calendar" : "VCS/ICS-naptár",
    "CSS stylesheet" : "CSS-stíluslap",
    "CSV document" : "CSV-dokumentum",
    "HTML document" : "HTML-dokumentum",
    "Markdown document" : "Markdown-dokumentum",
    "Org-mode file" : "Org-mode-fájl",
    "Plain text document" : "Egyszerű szöveges dokumentum",
    "Rich Text document" : "Rich Text-dokumentum",
    "Electronic business card" : "Elektronikus névjegykártya",
    "C++ source code" : "C++-forráskód",
    "LDIF address book" : "LDIF-címjegyzék",
    "NFO document" : "NFO-dokumentum",
    "PHP source" : "PHP-forráskód",
    "Python script" : "Python-parancsfájl",
    "ReStructuredText document" : "ReStructuredText-dokumentum",
    "3GPP multimedia file" : "3GPP-multimédiafájl",
    "MPEG video" : "MPEG-videó",
    "DV video" : "DV-videó",
    "MPEG-2 transport stream" : "MPEG-2 átviteli adatfolyam",
    "MPEG-4 video" : "MPEG-4-videó",
    "Ogg video" : "Ogg-videó",
    "QuickTime video" : "QuickTime-videó",
    "WebM video" : "WebM-videó",
    "Flash video" : "FLash-videó",
    "Matroska video" : "Matroska-videó",
    "Windows Media video" : "Windows Media-videó",
    "AVI video" : "AVI-videó",
    "Done" : "Kész",
    "Scan QR code to log in" : "Olvassa le a QR-kódot a bejelentkezéshez",
    "Use {productName} mobile client you want to connect to scan the code" : "Használja a hozzákapcsolandó {productName} mobilklienst a kód leolvasásához",
    "Code will expire {timeCountdown} or after use" : "A kód {timeCountdown} vagy a használat után lejár",
    "Applications menu" : "Alkalmazások menü",
    "Apps" : "Alkalmazások",
    "More apps" : "További alkalmazások",
    "_{count} notification_::_{count} notifications_" : ["{count} értesítés","{count} értesítés"],
    "No" : "Nem",
    "Yes" : "Igen",
    "App password" : "Alkalmazásjelszó",
    "Grant access" : "Hozzáférés megadása",
    "The remote URL must include the user." : "A távoli webcímnek tartalmaznia kell a felhasználót.",
    "Invalid remote URL." : "Érvénytelen távoli webcím.",
    "Failed to add the public link to your Nextcloud" : "Nem sikerült hozzáadni a nyilvános hivatkozást a Nexcloudjához",
    "Federated user" : "Föderált felhasználó",
    "user@your-nextcloud.org" : "felhasználó@az-ön-nextcloudja.org",
    "Create share" : "Megosztás létrehozása",
    "Direct link copied" : "Közvetlen hivatkozás másolva",
    "Please copy the link manually:" : "Másolja kézileg a hivatkozást:",
    "Custom date range" : "Egyéni dátumtartomány",
    "Pick start date" : "Válasszon kezdési dátumot",
    "Pick end date" : "Válasszon befejezési dátumot",
    "Search in date range" : "Keresés a dátumtartományban",
    "Search in current app" : "Keresés a jelenlegi alkalmazásban",
    "Clear search" : "Keresés törlése",
    "Search everywhere" : "Keresés mindenhol",
    "Searching …" : "Keresés…",
    "Start typing to search" : "Kezdjen el gépelni a kereséshez",
    "Minimum search length is {minSearchLength} characters" : "A legkisebb keresési hossz {minSearchLength} karakteres",
    "No matching results" : "Nincs találat",
    "Today" : "Ma",
    "Last 7 days" : "Előző 7 nap",
    "Last 30 days" : "Előző 30 nap",
    "This year" : "Ezen az éven",
    "Last year" : "Előző év",
    "Between {startDate} and {endDate}" : "{startDate} és {endDate} között",
    "Unified search" : "Egyesített keresés",
    "Search apps, files, tags, messages" : "Alkalmazások, fájlok, címkék és üzenetek keresése",
    "Places" : "Helyek",
    "Date" : "Dátum",
    "Search people" : "Emberek keresése",
    "People" : "Emberek",
    "Filter in current view" : "Jelenlegi nézet szűrése",
    "Search connected services" : "Összekapcsolt szolgáltatások keresése",
    "Results" : "Eredmények",
    "Load more results" : "További találatok betöltése",
    "Search in" : "Keresés ebben:",
    "Partial matches" : "Részleges egyezések",
    "Log in" : "Bejelentkezés",
    "Logging in …" : "Bejelentkezés…",
    "Log in to {productName}" : "Bejelentkezés ebbe: {productName}",
    "Wrong login or password." : "Hibás bejelentkezés vagy jelszó.",
    "This account is disabled" : "Ez a fiók le van tiltva",
    "Too many incorrect login attempts. Please try again in 30 seconds." : "Túl sok helytelen bejelentkezési kísérlet. Próbálja újra 30 másodperc múlva.",
    "Account name or email" : "Fióknév vagy e-mail-cím",
    "Account name" : "Fiók neve",
    "Server side authentication failed!" : "A kiszolgálóoldali hitelesítés sikertelen.",
    "Please contact your administrator." : "Lépjen kapcsolatba a rendszergazdával.",
    "Session error" : "Munkamenethiba",
    "It appears your session token has expired, please refresh the page and try again." : "Úgy tűnik, hogy a munkamenettoken lejárt, frissítse az oldalt, és próbálja újra.",
    "An internal error occurred." : "Belső hiba történt.",
    "Please try again or contact your administrator." : "Próbálja meg újra, vagy vegye fel a kapcsolatot a rendszergazdával.",
    "Password" : "Jelszó",
    "Remember me" : "Bejelentkezés megjegyzése",
    "Log in with a device" : "Bejelentkezés eszközzel",
    "Login or email" : "Bejelentkezés vagy e-mail",
    "Your account is not setup for passwordless login." : "A fiókja nincs beállítva jelszómentes bejelentkezésre.",
    "Your connection is not secure" : "A kapcsolat nem biztonságos",
    "Passwordless authentication is only available over a secure connection." : "A jelszó nélküli hitelesítés csak biztonságos kapcsolaton keresztül érhető el.",
    "Browser not supported" : "A böngésző nem támogatott",
    "Passwordless authentication is not supported in your browser." : "A jelszó nélküli hitelesítést nem támogatja a böngészője.",
    "Reset password" : "Jelszó-visszaállítás",
    "Back to login" : "Vissza a bejelentkezéshez",
    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "Ha a fiók létezik, akkor egy jelszó-visszaállítási üzenet lett küldve az e-mail-címére. Ha nem kapja meg, akkor ellenőrizze az e-mail-címet és a bejelentkezést, nézze meg a levélszemét mappáját vagy kérje a helyi rendszergazda segítségét.",
    "Couldn't send reset email. Please contact your administrator." : "Nem küldhető visszaállítási e-mail. Lépjen kapcsolatba a rendszergazdával.",
    "Password cannot be changed. Please contact your administrator." : "A jelszó nem módosítható. Lépjen kapcsolatba a rendszergazdával.",
    "New password" : "Új jelszó",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "A fájljai titkosítva vannak. A jelszó visszaállítása után sehogy sem fogja tudja visszaszerezni azokat. Ha nem tudja mi a teendő, akkor beszéljen a helyi rendszergazdával. Biztos, hogy folytatja?",
    "I know what I'm doing" : "Tudom mit csinálok",
    "Resetting password" : "Jelszó visszaállítása",
    "Schedule work & meetings, synced with all your devices." : "Ütemezett munkáját és találkozóit, szinkronizálva az összes eszközén.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Tartsa egy helyen kollégáit és barátait, anélkül hogy kiszivárogtatná a személyes adataikat.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Egyszerű e-mail alkalmazás, amely szépen integrálódik a Fájlok, Névjegyek és Naptár alkalmazásba.",
    "Chatting, video calls, screen sharing, online meetings and web conferencing – in your browser and with mobile apps." : "Csevegés, videóhívások, képernyőmegosztás, online megbeszélések és webes konferencia – a böngészőjében és mobilalkalmazásokkal.",
    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Közösen szerkeszthető dokumentumok, táblázatok és bemutatók, a Collabora Online-ra építve.",
    "Distraction free note taking app." : "Figyelemelterelés nélküli jegyzetelési alkalmazás.",
    "Recommended apps" : "Ajánlott alkalmazások",
    "Loading apps …" : "Alkalmazások betöltése…",
    "Could not fetch list of apps from the App Store." : "Az alkalmazások listája nem kérhető le az alkalmazástárból.",
    "App download or installation failed" : "Alkalmazás letöltése vagy telepítése sikertelen",
    "Cannot install this app because it is not compatible" : "Az alkalmazás nem telepíthető, mert nem kompatibilis",
    "Cannot install this app" : "Az alkalmazás nem telepíthető",
    "Skip" : "Kihagyás",
    "Installing apps …" : "Alkalmazások telepítése…",
    "Install recommended apps" : "Javasolt alkalmazások telepítése",
    "Online" : "Elérhető",
    "Away" : "Távol",
    "Busy" : "Foglalt",
    "Do not disturb" : "Ne zavarjanak",
    "Mute all notifications" : "Összes értesítés némítása",
    "Invisible" : "Láthatatlan",
    "Appear offline" : "Megjelenés nem kapcsolódottként",
    "Avatar of {displayName}" : "{displayName} profilképe",
    "Settings menu" : "Beállítások menü",
    "Loading your contacts …" : "Névjegyek betöltése…",
    "Looking for {term} …" : "{term} keresése…",
    "Search contacts" : "Névjegyek keresése",
    "Filter by team" : "Szűrés csapat szerint",
    "All teams" : "Összes csapat",
    "Search contacts in team {team}" : "Névjegyek keresése a(z) {team} csapatban",
    "Search contacts …" : "Névjegyek keresése…",
    "Reset search" : "Keresés visszaállítása",
    "Could not load your contacts" : "Nem lehet betölteni a névjegyeit",
    "No contacts found" : "Nem találhatók névjegyek",
    "Contacts list" : "Névjegylista",
    "Show all contacts" : "Összes névjegy megjelenítése",
    "Install the Contacts app" : "A Névjegyek alkalmazás telepítése",
    "Search" : "Keresés",
    "No results for {query}" : "Nincs találat a következőre: {query}",
    "Press Enter to start searching" : "A keresés indításához nyomjon Entert",
    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["A kereséshez írjon be a legalább {minSearchLength} karaktert","A kereséshez írjon be a legalább {minSearchLength} karaktert"],
    "An error occurred while searching for {type}" : "Hiba történt a(z) {type} keresése sorá",
    "Search starts once you start typing and results may be reached with the arrow keys" : "A keresés elindul, ha elkezd gépelni, és a találatok a nyílbillentyűkkel érhetők el",
    "Search for {name} only" : "Keresés csak a(z) {name} kifejezésre",
    "Loading more results …" : "További találatok betöltése…",
    "Forgot password?" : "Elfelejtett jelszó?",
    "Back to login form" : "Vissza a bejelentkezési űrlaphoz",
    "Back" : "Vissza",
    "Login form is disabled." : "A bejelentkezési űrlap letiltva.",
    "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "A Nextcloud bejelentkezési űrlap le van tiltva. Használjon más bejelentkezési lehetőséget, ha van ilyen, vagy lépjen kapcsolatba az adminisztrációval.",
    "Connect to your account" : "Kapcsolódás a fiókjához",
    "Please log in before granting \"{client}\" access to your {instanceName} account." : "Jelentkezzen be mielőtt hozzáférést biztosít a(z) „{client}” számára ehhez a fiókjához: {instanceName}.",
    "Security warning" : "Biztonsági figyelmeztetés",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Ha nem új eszközt vagy alkalmazást próbál beállítani, akkor valaki megpróbálja becsapni, hogy hozzáférést biztosítson számára az adatokhoz. Ebben az esetben ne folytassa, hanem lépjen kapcsolatba a rendszergazdával.",
    "Log in using password" : "Bejelentkezés jelszó használatával ",
    "Alternative log in using app password" : "Alternatív bejelentkezés alkalmazásjelszó segítségével",
    "Account connected" : "Fiók csatlakoztatva",
    "Your client should now be connected!" : "A kliens most már kapcsolódik.",
    "You can close this window." : "Bezárhatja ezt az ablakot.",
    "Account access" : "Fiókhozzáférés",
    "Currently logged in as {userDisplayName} ({userId})." : "Jelenleg bejelentkezve: {userDisplayName} ({userId}).",
    "You are about to grant \"{client}\" access to your {instanceName} account." : "Hozzáférést készül biztosítani a(z) „{client}” számára ehhez a fiókjához: {instanceName}.",
    "More actions" : "További műveletek",
    "User menu" : "Felhasználói menü",
    "Your guest name: {user}" : "A vendég neve: {user}",
    "You are currently not identified." : "Jelenleg nincs azonosítva.",
    "Set public name" : "Nyilvános név beállítása",
    "Change public name" : "Nyilvános név módosítása",
    "This share is password-protected" : "Ez a megosztás jelszóval védett",
    "The password is wrong or expired. Please try again or request a new one." : "A jelszó hibás vagy lejárt. Próbálja újra, vagy kérjen újat.",
    "Submit" : "Beküldés",
    "Please type in your email address to request a temporary password" : "Írja be az e-mail-címét, hogy ideiglenes jelszót kérjen",
    "Password sent!" : "Jelszó elküldve.",
    "You are not authorized to request a password for this share" : "Nincs jogosultsága, hogy jelszót kérjen ehhez a megosztáshoz",
    "Email address" : "E-mail-cím",
    "Request password" : "Jelszó kérése",
    "Forgot password" : "Elfelejtett jelszó",
    "Password is too weak" : "Jelszó túl gyenge",
    "Password is weak" : "A jelszó gyenge",
    "Password is average" : "A jelszó átlagos",
    "Password is strong" : "A jelszó erős",
    "Password is very strong" : "A jelszó nagyon erős",
    "Password is extremely strong" : "A jelszó kiemelkedően erős",
    "Unknown password strength" : "Ismeretlen jelszóerősség",
    "Your data directory and files are probably accessible from the internet because the <code>.htaccess</code> file does not work." : "Az adatkönyvtára és a fájljai valószínűleg elérhetőek az internetről, mert a <code>.htaccess</code> fájl nem működik.",
    "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "A kiszolgáló helyes beállításához {linkStart}tekintse meg a dokumentációt{linkEnd}",
    "Autoconfig file detected" : "Autoconfig fájl felismerve",
    "The setup form below is pre-filled with the values from the config file." : "A lenti beállítási űrlap a konfigurációs fájlban lévő értékekkel van előre kitöltve.",
    "Create administration account" : "Rendszergazdai fiók létrehozása",
    "Administration account name" : "Rendszergazdai fiók neve",
    "Administration account password" : "Rendszergazdai fiók jelszava",
    "Storage & database" : "Tárhely és adatbázis",
    "Data folder" : "Adatmappa",
    "Database configuration" : "Adatbázis-beállítások",
    "Database type" : "Adatbázistípus",
    "Only {firstAndOnlyDatabase} is available." : "Csak a(z) {firstAndOnlyDatabase} érhető el.",
    "Install and activate additional PHP modules to choose other database types." : "Telepítse és aktiválja a bővített PHP modulokat, hogy tudjon más adatbázis típust is kiválasztani.",
    "For more details check out the documentation." : "További részletekért nézze meg a dokumentációt.",
    "Performance warning" : "Teljesítménybeli figyelmeztetés",
    "You chose SQLite as database." : "SQLite adatbázist választott.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "Az SQLite-ot csak minimális és fejlesztési célú példányok esetén szabad használni. Éles működés esetén más adatbázis-kezelőt ajánlunk.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Ha klienseket használt a fájlszinkronizáláshoz, akkor az SQLite használata erősen ellenjavallt.",
    "Database connection" : "Adatbázis-kapcsolat",
    "Database user" : "Adatbázis-felhasználó",
    "Database password" : "Adatbázisjelszó",
    "Database name" : "Adatbázis neve",
    "Database tablespace" : "Adatbázis táblatere",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Adja meg a port számát a kiszolgáló neve után (például localhost:5432).",
    "Database host" : "Adatbázis-kiszolgáló",
    "localhost" : "localhost",
    "Installing …" : "Telepítés…",
    "Install" : "Telepítés",
    "Need help?" : "Segítségre van szüksége?",
    "See the documentation" : "Nézze meg a dokumentációt",
    "{name} version {version} and above" : "{name} {version} verziója, és újabb",
    "This browser is not supported" : "Ez a böngésző nem támogatott",
    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "A böngészője nem támogatott. Frissítsen újabb verzióra, vagy váltson egy támogatott böngészőre.",
    "Continue with this unsupported browser" : "Folytatás ezzel a nem támogatott böngészővel",
    "Supported versions" : "Támogatott verziók",
    "The update completed with warnings. Please check the details for more information." : "A frissítés figyelmeztetésekkel fejeződött be. További információkért ellenőrizze a részleteket.",
    "The update completed successfully." : "A frissítés sikeresen befejeződött",
    "Preparing update…" : "Frissítés előkészítése…",
    "You will be redirected to {productName} in {count} seconds." : "{count} másodpercen belül át lesz irányítva ide: {productName}.",
    "The update is in progress, leaving this page might interrupt the process in some environments." : "A frissítés folyamatban van, az oldal elhagyása egyes környezetekben megszakíthatja a folyamatot.",
    "App update required" : "Alkalmazásfrissítés szükséges",
    "{productName} will be updated to version {version}" : "A(z) {productName} frissítve lesz erre a verzióra: {version}",
    "The theme {oldTheme} has been disabled." : "A(z) {oldTheme} téma le lett tiltva.",
    "These incompatible apps will be disabled:" : "A következő nem kompatibilis alkalmazások le lesznek tiltva:",
    "Incompatible apps" : "Nem kompatibilis alkalmazások",
    "These apps will be updated:" : "A következő alkalmazások lesznek frissítve:",
    "Apps to update" : "Frissítendő alkalmazások",
    "{app} from {oldVersion} to {version}" : "{app} erről: {oldVersion}, erre: {version}",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Gondoskodjon róla, hogy elmentse az adatbázist, a konfigurációs mappa és az adatmappa tartalmát, mielőtt folytatja.",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "A nagy méretű telepítések által okozott időtúllépések elkerülése érdekében, inkább futtassa a következő parancsot a telepítési alkönyvtárban:",
    "Start update" : "A frissítés megkezdése",
    "Continue to {productName}" : "Tovább erre: {productName}",
    "Update to {version}" : "Frissítés erre: {version}",
    "Hide details" : "Részletek elrejtése",
    "Show details" : "Részletek megjelenítése",
    "Update details" : "Frissítés részletei",
    "Update needed" : "Frissítés szükséges",
    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Használja a parancssori frissítőt, mert 50 fiókosnál nagyobb példánya van.",
    "Documentation" : "Dokumentáció",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Tudomásul veszem, hogy a webes frissítési felület használata közben fellépő időtúllépés adatvesztéssel járhat. Van biztonsági mentésem, hiba esetén tudom, hogyan állítsam vissza az adatokat.",
    "Upgrade via web on my own risk" : "Frissítés weben keresztül, saját felelősségre",
    "Search {types} …" : "{types} keresése…",
    "Choose {file}" : "{file} kiválasztása",
    "Choose" : "Válasszon",
    "Copy to {target}" : "Másolás ide: {target}",
    "Copy" : "Másolás",
    "Move to {target}" : "Áthelyezés ide: {target}",
    "Move" : "Áthelyezés",
    "OK" : "OK",
    "read-only" : "csak olvasható",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} fájl ütközik","{count} fájl ütközik"],
    "One file conflict" : "Egy fájl ütközik",
    "New Files" : "Új fájlok",
    "Already existing files" : "Meglévő fájlok",
    "Which files do you want to keep?" : "Mely fájlokat akarja megtartani?",
    "If you select both versions, the copied file will have a number added to its name." : "Ha mindkét verziót kiválasztja, a másolt fájlok neve sorszámozva lesz.",
    "Cancel" : "Mégse",
    "Continue" : "Folytatás",
    "(all selected)" : "(összes kiválasztva)",
    "({count} selected)" : "({count} kiválasztva)",
    "Error loading file exists template" : "Hiba a „fájl már létezik” sablon betöltésekor",
    "Saving …" : "Mentés…",
    "Groups" : "Csoportok",
    "Group list is empty" : "A csoportlista üres",
    "Unable to retrieve the group list" : "A csoportlista betöltése sikertelen",
    "seconds ago" : "pár másodperce",
    "Add to a project" : "Hozzáadás egy projekthez",
    "Rename project" : "Projekt átnevezése",
    "Failed to rename the project" : "A projekt átnevezése sikertelen",
    "Failed to create a project" : "A projekt létrehozása sikertelen",
    "Failed to add the item to the project" : "Az elem hozzáadása a projekthez sikertelen",
    "Connect items to a project to make them easier to find" : "Kössön hozzá elemeket a projekthez, hogy könnyebben megtalálhatóak legyenek",
    "Type to search for existing projects" : "Gépeljen a meglévő projektet kereséséhez",
    "Close \"{dialogTitle}\" dialog" : "A(z) „{dialogTitle}” párbeszédablak bezárása",
    "Email length is at max (255)" : "Az e-mail-cím hossza elérte a maximumot (255)",
    "Clipboard not available, please copy manually" : "A vágólap nem érhető el, másolja kézileg",
    "Personal" : "Személyes",
    "Accounts" : "Fiókok",
    "Admin" : "Rendszergazda",
    "Help" : "Súgó",
    "Access forbidden" : "A hozzáférés nem engedélyezett",
    "You are not allowed to access this page." : "Nem férhet hozzá ehhez az oldalhoz.",
    "Back to %s" : "Vissza ide %s",
    "Page not found" : "Az oldal nem található",
    "The page could not be found on the server or you may not be allowed to view it." : "Az oldal nem található a kiszolgálón, vagy lehet, hogy nincs engedélye arra, hogy megnézze.",
    "Too many requests" : "Túl sok kérés",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Túl sok kérés érkezett a hálózatától. Próbálja újra később, vagy ha ez egy hiba, akkor forduljon a rendszergazdához.",
    "Error" : "Hiba",
    "Internal Server Error" : "Belső kiszolgálóhiba",
    "The server was unable to complete your request." : "A szerver nem tudta végrehajtani a kérésed.",
    "If this happens again, please send the technical details below to the server administrator." : "Ha ez még egyszer előfordul küldd el az alábbi technikai részleteket a rendszergazdának.",
    "More details can be found in the server log." : "További részletek találhatók a kiszolgáló naplójában.",
    "For more details see the documentation ↗." : "További részletekért nézze meg a dokumentációt ↗.",
    "Technical details" : "Műszaki adatok",
    "Remote Address: %s" : "Távoli cím: %s",
    "Request ID: %s" : "Kérésazonosító: %s",
    "Type: %s" : "Típus: %s",
    "Code: %s" : "Kód: %s",
    "Message: %s" : "Üzenet: %s",
    "File: %s" : "Fájl: %s",
    "Line: %s" : "Sor: %s",
    "Trace" : "Nyomkövetés",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Úgy néz ki, hogy a Nextcloud újratelepítésére készül. Viszont a CAN_INSTALL fájl hiányzik a config könyvtárból. A folytatáshoz hozza létre a CAN_INSTALL fájlt a konfigurációs mappában.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "A CAN_INSTALL nem távolítható el a konfigurációs mappából. Törölje a fájlt kézileg.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Az alkalmazás megfelelő működéséhez JavaScript szükséges. {linkstart}Engedélyezze a JavaScriptet{linkend}, és frissítse a lapot.",
    "Skip to main content" : "Ugrás a fő tartalomhoz",
    "Skip to navigation of app" : "Ugrás az alkalmazás navigációjához",
    "Go to %s" : "Ugrás ide: %s",
    "Get your own free account" : "Szerezzen saját ingyenes fiókot",
    "Previous" : "Előző",
    "Two-factor authentication" : "Kétfaktoros hitelesítés",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "A fokozott biztonság engedélyezett a fiókja számára. Válasszon egy második faktort a hitelesítéshez:",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Nem lehet betölteni legalább egy engedélyezett kétfaktoros hitelesítési módot. Lépjen kapcsolatba a rendszergazdával.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "A kétfaktoros hitelesítés kötelező, de még nem lett beállítva a fiókjához. Segítségért lépjen kapcsolatba a rendszergazdával.",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "A kétfaktoros hitelesítés be van tartatva, de nincs beállítva a fiókján. Folytassa a kétfaktoros hitelesítés beállításával.",
    "Set up two-factor authentication" : "Kétfaktoros hitelesítés beállítása",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "A kétfaktoros hitelesítés be van tartatva, de nincs beállítva a fiókján. Használja a biztonsági kódjai egyikét a bejelentkezéshez, vagy ha segítségre van szüksége, akkor lépjen kapcsolatba a rendszergazdával.",
    "Use backup code" : "Biztonsági kód használata",
    "Cancel login" : "Bejelentkezés megszakítása",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "A fokozott biztonság be van tartatva a fiókjánál. Válassza ki a beállítandó szolgáltatót:",
    "Error while validating your second factor" : "Hiba történt a második faktor évényesítésekor",
    "Access through untrusted domain" : "Nem megbízható tartományon keresztüli hozzáférés",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Lépjen kapcsolatba a rendszergazdával. Ha Ön az, akkor szerkessze a „trusted_domains” beállítást a config/config.php-ban, a config.sample.php-hoz hasonlóan.",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Ennek a beállításához további információkat talál a %1$sdokumentációban%2$s.",
    "Maintenance mode" : "Karbantartási üzemmód",
    "This %s instance is currently in maintenance mode, which may take a while." : "Ez a %s példány éppen karbantartási üzemmódban van, amely eltarthat egy darabig.",
    "This page will refresh itself when the instance is available again." : "Ez az oldal frissíteni fogja magát, amint a példány ismét elérhető lesz.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Ha ez az üzenet mindig vagy váratlanul megjelenik, akkor keresse fel a rendszergazdáját.",
    "Error occurred while checking server setup" : "Hiba történt a kiszolgálóbeállítások ellenőrzésekor",
    "For more details see the {linkstart}documentation ↗{linkend}." : "További részletekért lásd a {linkstart}dokumentációt↗{linkend}.",
    "unknown text" : "ismeretlen szöveg",
    "Hello world!" : "Helló világ!",
    "sunny" : "napos",
    "Hello {name}, the weather is {weather}" : "Üdv {name}, {weather} időnk van",
    "Hello {name}" : "Üdv {name}!",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Ezek a találatok<script>alert(1)</script></strong>",
    "new" : "új",
    "_download %n file_::_download %n files_" : ["%n fájl letöltése","%n fájl letöltése"],
    "An error occurred." : "Hiba történt.",
    "Please reload the page." : "Frissítse az oldalt.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "A frissítés sikertelen. Bővebb információért <a href=\"{url}\">keresse fel a problémáról szóló fórumbejegyzésünket</a>.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "A frissítés sikertelen. Jelezze a problémát a <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud közösségnek</a>.",
    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["A frissítés sikeres volt. %n másodperc múlva át lesz irányítva a következőhöz: {productName}.","A frissítés sikeres volt. %n másodperc múlva át lesz irányítva a következőhöz: {productName}."],
    "Direct link copied to clipboard" : "Közvetlen hivatkozás a vágólapra másolva",
    "Searching …" : "Keresés…",
    "Logging in …" : "Bejelentkezés…",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Többszöri sikertelen bejelentkezési kísérletet észleltünk az IP-címéről. A legközelebbi kísérlete így 30 másodperccel késleltetve lesz.",
    "Loading apps …" : "Alkalmazások betöltése…",
    "Installing apps …" : "Alkalmazások telepítése…",
    "Loading your contacts …" : "Névjegyek betöltése…",
    "Looking for {term} …" : "{term} keresése…",
    "Search contacts …" : "Névjegyek keresése…",
    "Loading more results …" : "További találatok betöltése…",
    "Search {types} …" : "{types} keresése…",
    "Saving …" : "Mentés…",
    "Connection to server lost" : "A kapcsolat megszakadt a kiszolgálóval",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Probléma az oldal betöltésekor, újratöltés %n másodperc múlva","Probléma az oldal betöltésekor, újratöltés %n másodperc múlva"],
    "New in" : "Újdonságok a következőben:",
    "View changelog" : "Változásnapló megtekintése",
    "Very weak password" : "Nagyon gyenge jelszó",
    "Weak password" : "Gyenge jelszó",
    "So-so password" : "Nem túl jó jelszó",
    "Good password" : "Megfelelő jelszó",
    "Strong password" : "Erős jelszó",
    "No action available" : "Nincs elérhető művelet",
    "Error fetching contact actions" : "Hiba a kapcsolati műveletek lekérésekor",
    "Non-existing tag #{tag}" : "Nem létező címke #{tag}",
    "Restricted" : "Korlátozott",
    "Delete" : "Törlés",
    "Rename" : "Átnevezés",
    "Collaborative tags" : "Együttműködési címkék",
    "No tags found" : "Nem találhatók címkék",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Az adatkönyvtár és a benne levő fájlok valószínűleg közvetlenül is elérhetők az internetről, mert a .htaccess fájl nem érvényesül.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "További információkért a szervered helyes beállításához nézd meg a <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentációt</a>.",
    "<strong>Create an admin account</strong>" : "<strong>Rendszergazdai fiók létrehozása</strong>",
    "New admin account name" : "Új rendszergazdai fiók neve",
    "New admin password" : "Új rendszergazdai fiók jelszava",
    "Show password" : "Jelszó megjelenítése",
    "Toggle password visibility" : "Jelszó láthatósága be/ki",
    "Configure the database" : "Adatbázis konfigurálása",
    "Only %s is available." : "Csak %s érhető el.",
    "Database account" : "Adatbázisfiók",
    "Installing …" : "Telepítés…",
    "Please log in before granting %1$s access to your %2$s account." : "Lépjen be mielőtthozzáférést biztosít a(z) %1$s kliensnek a(z) %2$s fiókjához.",
    "Currently logged in as %1$s (%2$s)." : "Jelenleg bejelentkezve: %1$s (%2$s).",
    "You are about to grant %1$s access to your %2$s account." : "Hozzáférést készül biztosítani %1$s számára ehhez a fiókjához: %2$s.",
    "%1$s will be updated to version %2$s" : "A(z) %1$s frissítve lesz erre a verzióra: %2$s",
    "The following apps will be updated:" : "A következő alkalmazások lesznek frissítve:",
    "The theme %s has been disabled." : "A(z) %s téma letiltásra került.",
    "Detailed logs" : "Részletes naplók",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Segítségért tekintse meg a <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">dokumentációt</a>."
},
"nplurals=2; plural=(n != 1);");
